Class: Aws::CloudTrail::Types::CreateTrailResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Returns the objects or data listed below if successful. Otherwise, returns an error.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watch_logs_log_group_arnString

Specifies the Amazon Resource Name (ARN) of the log group to which CloudTrail logs will be delivered.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_watch_logs_role_arnString

Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#include_global_service_eventsBoolean

Specifies whether the trail is publishing events from global services such as IAM to the log files. Setting this value to true only delivers global service events to the trail if the trail is multi-Region or if the trail's home Region is the partition leader Region (for example, us-east-1).



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#is_multi_region_trailBoolean

Specifies whether the trail exists in one Region or in all Regions.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#is_organization_trailBoolean

Specifies whether the trail is an organization trail.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

Specifies the KMS key ID that encrypts the events delivered by CloudTrail. The value is a fully specified ARN to a KMS key in the following format.

arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#log_file_validation_enabledBoolean

Specifies whether log file integrity validation is enabled.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Specifies the name of the trail.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#recursive_loggingBoolean

Specifies whether recursive logging is enabled for the trail.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_nameString

Specifies the name of the Amazon S3 bucket designated for publishing log files.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#s3_key_prefixString

Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_arnString

Specifies the ARN of the Amazon SNS topic that CloudTrail uses to send notifications when log files are delivered. The format of a topic ARN is:

arn:aws:sns:us-east-2:123456789012:MyTopic



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_nameString

This field is no longer in use. Use SnsTopicARN.



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#trail_arnString

Specifies the ARN of the trail that was created. The format of a trail ARN is:

arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail



1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1061

class CreateTrailResponse < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end