Class: Aws::CloudTrail::Types::DescribeQueryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::DescribeQueryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delivery_s3_uri ⇒ String
The URI for the S3 bucket where CloudTrail delivered query results, if applicable.
-
#delivery_status ⇒ String
The delivery status.
-
#error_message ⇒ String
The error message returned if a query failed.
-
#event_data_store_owner_account_id ⇒ String
The account ID of the event data store owner.
-
#prompt ⇒ String
The prompt used for a generated query.
-
#query_id ⇒ String
The ID of the query.
-
#query_statistics ⇒ Types::QueryStatisticsForDescribeQuery
Metadata about a query, including the number of events that were matched, the total number of events scanned, the query run time in milliseconds, and the query's creation time.
-
#query_status ⇒ String
The status of a query.
-
#query_string ⇒ String
The SQL code of a query.
Instance Attribute Details
#delivery_s3_uri ⇒ String
The URI for the S3 bucket where CloudTrail delivered query results, if applicable.
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1459 class DescribeQueryResponse < Struct.new( :query_id, :query_string, :query_status, :query_statistics, :error_message, :delivery_s3_uri, :delivery_status, :prompt, :event_data_store_owner_account_id) SENSITIVE = [] include Aws::Structure end |
#delivery_status ⇒ String
The delivery status.
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1459 class DescribeQueryResponse < Struct.new( :query_id, :query_string, :query_status, :query_statistics, :error_message, :delivery_s3_uri, :delivery_status, :prompt, :event_data_store_owner_account_id) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
The error message returned if a query failed.
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1459 class DescribeQueryResponse < Struct.new( :query_id, :query_string, :query_status, :query_statistics, :error_message, :delivery_s3_uri, :delivery_status, :prompt, :event_data_store_owner_account_id) SENSITIVE = [] include Aws::Structure end |
#event_data_store_owner_account_id ⇒ String
The account ID of the event data store owner.
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1459 class DescribeQueryResponse < Struct.new( :query_id, :query_string, :query_status, :query_statistics, :error_message, :delivery_s3_uri, :delivery_status, :prompt, :event_data_store_owner_account_id) SENSITIVE = [] include Aws::Structure end |
#prompt ⇒ String
The prompt used for a generated query. For information about generated queries, see Create CloudTrail Lake queries from natural language prompts in the CloudTrail user guide.
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1459 class DescribeQueryResponse < Struct.new( :query_id, :query_string, :query_status, :query_statistics, :error_message, :delivery_s3_uri, :delivery_status, :prompt, :event_data_store_owner_account_id) SENSITIVE = [] include Aws::Structure end |
#query_id ⇒ String
The ID of the query.
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1459 class DescribeQueryResponse < Struct.new( :query_id, :query_string, :query_status, :query_statistics, :error_message, :delivery_s3_uri, :delivery_status, :prompt, :event_data_store_owner_account_id) SENSITIVE = [] include Aws::Structure end |
#query_statistics ⇒ Types::QueryStatisticsForDescribeQuery
Metadata about a query, including the number of events that were matched, the total number of events scanned, the query run time in milliseconds, and the query's creation time.
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1459 class DescribeQueryResponse < Struct.new( :query_id, :query_string, :query_status, :query_statistics, :error_message, :delivery_s3_uri, :delivery_status, :prompt, :event_data_store_owner_account_id) SENSITIVE = [] include Aws::Structure end |
#query_status ⇒ String
The status of a query. Values for QueryStatus include QUEUED,
RUNNING, FINISHED, FAILED, TIMED_OUT, or CANCELLED
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1459 class DescribeQueryResponse < Struct.new( :query_id, :query_string, :query_status, :query_statistics, :error_message, :delivery_s3_uri, :delivery_status, :prompt, :event_data_store_owner_account_id) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The SQL code of a query.
1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1459 class DescribeQueryResponse < Struct.new( :query_id, :query_string, :query_status, :query_statistics, :error_message, :delivery_s3_uri, :delivery_status, :prompt, :event_data_store_owner_account_id) SENSITIVE = [] include Aws::Structure end |