Class: Aws::CloudTrail::Types::EnableFederationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_data_storeString

The ARN (or ID suffix of the ARN) of the event data store for which you want to enable Lake query federation.



1613
1614
1615
1616
1617
1618
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1613

class EnableFederationRequest < Struct.new(
  :event_data_store,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#federation_role_arnString

The ARN of the federation role to use for the event data store. Amazon Web Services services like Lake Formation use this federation role to access data for the federated event data store. The federation role must exist in your account and provide the required minimum permissions.



1613
1614
1615
1616
1617
1618
# File 'lib/aws-sdk-cloudtrail/types.rb', line 1613

class EnableFederationRequest < Struct.new(
  :event_data_store,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end