Class: Aws::CloudTrail::Types::GetImportResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestampTime

The timestamp of the import's creation.



2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2381

class GetImportResponse < Struct.new(
  :import_id,
  :destinations,
  :import_source,
  :start_event_time,
  :end_event_time,
  :import_status,
  :created_timestamp,
  :updated_timestamp,
  :import_statistics)
  SENSITIVE = []
  include Aws::Structure
end

#destinationsArray<String>

The ARN of the destination event data store.



2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2381

class GetImportResponse < Struct.new(
  :import_id,
  :destinations,
  :import_source,
  :start_event_time,
  :end_event_time,
  :import_status,
  :created_timestamp,
  :updated_timestamp,
  :import_statistics)
  SENSITIVE = []
  include Aws::Structure
end

#end_event_timeTime

Used with StartEventTime to bound a StartImport request, and limit imported trail events to only those events logged within a specified time period.



2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2381

class GetImportResponse < Struct.new(
  :import_id,
  :destinations,
  :import_source,
  :start_event_time,
  :end_event_time,
  :import_status,
  :created_timestamp,
  :updated_timestamp,
  :import_statistics)
  SENSITIVE = []
  include Aws::Structure
end

#import_idString

The ID of the import.



2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2381

class GetImportResponse < Struct.new(
  :import_id,
  :destinations,
  :import_source,
  :start_event_time,
  :end_event_time,
  :import_status,
  :created_timestamp,
  :updated_timestamp,
  :import_statistics)
  SENSITIVE = []
  include Aws::Structure
end

#import_sourceTypes::ImportSource

The source S3 bucket.



2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2381

class GetImportResponse < Struct.new(
  :import_id,
  :destinations,
  :import_source,
  :start_event_time,
  :end_event_time,
  :import_status,
  :created_timestamp,
  :updated_timestamp,
  :import_statistics)
  SENSITIVE = []
  include Aws::Structure
end

#import_statisticsTypes::ImportStatistics

Provides statistics for the import. CloudTrail does not update import statistics in real-time. Returned values for parameters such as EventsCompleted may be lower than the actual value, because CloudTrail updates statistics incrementally over the course of the import.



2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2381

class GetImportResponse < Struct.new(
  :import_id,
  :destinations,
  :import_source,
  :start_event_time,
  :end_event_time,
  :import_status,
  :created_timestamp,
  :updated_timestamp,
  :import_statistics)
  SENSITIVE = []
  include Aws::Structure
end

#import_statusString

The status of the import.



2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2381

class GetImportResponse < Struct.new(
  :import_id,
  :destinations,
  :import_source,
  :start_event_time,
  :end_event_time,
  :import_status,
  :created_timestamp,
  :updated_timestamp,
  :import_statistics)
  SENSITIVE = []
  include Aws::Structure
end

#start_event_timeTime

Used with EndEventTime to bound a StartImport request, and limit imported trail events to only those events logged within a specified time period.



2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2381

class GetImportResponse < Struct.new(
  :import_id,
  :destinations,
  :import_source,
  :start_event_time,
  :end_event_time,
  :import_status,
  :created_timestamp,
  :updated_timestamp,
  :import_statistics)
  SENSITIVE = []
  include Aws::Structure
end

#updated_timestampTime

The timestamp of when the import was updated.



2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2381

class GetImportResponse < Struct.new(
  :import_id,
  :destinations,
  :import_source,
  :start_event_time,
  :end_event_time,
  :import_status,
  :created_timestamp,
  :updated_timestamp,
  :import_statistics)
  SENSITIVE = []
  include Aws::Structure
end