Class: Aws::CloudTrail::Types::GetInsightSelectorsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_data_store_arnString

The ARN of the source event data store that enabled Insights events.

Returns:



2459
2460
2461
2462
2463
2464
2465
2466
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2459

class GetInsightSelectorsResponse < Struct.new(
  :trail_arn,
  :insight_selectors,
  :event_data_store_arn,
  :insights_destination)
  SENSITIVE = []
  include Aws::Structure
end

#insight_selectorsArray<Types::InsightSelector>

Contains the Insights types that are enabled on a trail or event data store. It also specifies the event categories on which a particular Insight type is enabled. ApiCallRateInsight and ApiErrorRateInsight are valid Insight types.The EventCategory field can specify Management or Data events or both. For event data store, you can log Insights for management events only.

Returns:



2459
2460
2461
2462
2463
2464
2465
2466
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2459

class GetInsightSelectorsResponse < Struct.new(
  :trail_arn,
  :insight_selectors,
  :event_data_store_arn,
  :insights_destination)
  SENSITIVE = []
  include Aws::Structure
end

#insights_destinationString

The ARN of the destination event data store that logs Insights events.

Returns:



2459
2460
2461
2462
2463
2464
2465
2466
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2459

class GetInsightSelectorsResponse < Struct.new(
  :trail_arn,
  :insight_selectors,
  :event_data_store_arn,
  :insights_destination)
  SENSITIVE = []
  include Aws::Structure
end

#trail_arnString

The Amazon Resource Name (ARN) of a trail for which you want to get Insights selectors.

Returns:



2459
2460
2461
2462
2463
2464
2465
2466
# File 'lib/aws-sdk-cloudtrail/types.rb', line 2459

class GetInsightSelectorsResponse < Struct.new(
  :trail_arn,
  :insight_selectors,
  :event_data_store_arn,
  :insights_destination)
  SENSITIVE = []
  include Aws::Structure
end