Class: Aws::CloudTrail::Types::InvalidInsightSelectorsException
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::CloudTrail::Types::InvalidInsightSelectorsException
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
For PutInsightSelectors, this exception is thrown when the
formatting or syntax of the InsightSelectors JSON statement is not
valid, or the specified InsightType in the InsightSelectors
statement is not valid. Valid values for InsightType are
ApiCallRateInsight and ApiErrorRateInsight. To enable Insights on
an event data store, the destination event data store specified by the
InsightsDestination parameter must log Insights events and the
source event data store specified by the EventDataStore parameter
must log management events.
For UpdateEventDataStore, this exception is thrown if Insights are
enabled on the event data store and the updated advanced event
selectors are not compatible with the configured InsightSelectors.
If the InsightSelectors includes an InsightType of
ApiCallRateInsight, the source event data store must log write
management events. If the InsightSelectors includes an InsightType
of ApiErrorRateInsight, the source event data store must log
management events.