Class: Aws::CloudTrail::Types::ListInsightsDataResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<Types::Event>

A list of events returned based on the InsightSource, DataType or Dimensions specified. The events list is sorted by time. The most recent event is listed first.

Returns:



3594
3595
3596
3597
3598
3599
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3594

class ListInsightsDataResponse < Struct.new(
  :events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use to get the next page of results after a previous API call. If the token does not appear, there are no more results to return. The token must be passed in with the same parameters as the previous call. For example, if the original call specified a EventName as a dimension with PutObject as a value, the call with NextToken should include those same parameters.

Returns:

  • (String)


3594
3595
3596
3597
3598
3599
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3594

class ListInsightsDataResponse < Struct.new(
  :events,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end