Class: Aws::CloudTrail::Types::ListInsightsMetricDataResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_codeString

Only returned if InsightType parameter was set to ApiErrorRateInsight.

If returning metrics for the ApiErrorRateInsight Insights type, this is the error to retrieve data for. For example, AccessDenied.



3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3745

class ListInsightsMetricDataResponse < Struct.new(
  :trail_arn,
  :event_source,
  :event_name,
  :insight_type,
  :error_code,
  :timestamps,
  :values,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#event_nameString

The name of the event, typically the Amazon Web Services API on which unusual levels of activity were recorded.



3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3745

class ListInsightsMetricDataResponse < Struct.new(
  :trail_arn,
  :event_source,
  :event_name,
  :insight_type,
  :error_code,
  :timestamps,
  :values,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#event_sourceString

The Amazon Web Services service to which the request was made, such as iam.amazonaws.com or s3.amazonaws.com.



3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3745

class ListInsightsMetricDataResponse < Struct.new(
  :trail_arn,
  :event_source,
  :event_name,
  :insight_type,
  :error_code,
  :timestamps,
  :values,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#insight_typeString

The type of CloudTrail Insights event, which is either ApiCallRateInsight or ApiErrorRateInsight. The ApiCallRateInsight Insights type analyzes write-only management API calls that are aggregated per minute against a baseline API call volume. The ApiErrorRateInsight Insights type analyzes management API calls that result in error codes.



3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3745

class ListInsightsMetricDataResponse < Struct.new(
  :trail_arn,
  :event_source,
  :event_name,
  :insight_type,
  :error_code,
  :timestamps,
  :values,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Only returned if the full results could not be returned in a single query. You can set the NextToken parameter in the next request to this value to continue retrieval.



3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3745

class ListInsightsMetricDataResponse < Struct.new(
  :trail_arn,
  :event_source,
  :event_name,
  :insight_type,
  :error_code,
  :timestamps,
  :values,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#timestampsArray<Time>

List of timestamps at intervals corresponding to the specified time period.



3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3745

class ListInsightsMetricDataResponse < Struct.new(
  :trail_arn,
  :event_source,
  :event_name,
  :insight_type,
  :error_code,
  :timestamps,
  :values,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#trail_arnString

Specifies the ARN of the trail. This is only returned when Insights is enabled on a trail logging data events.



3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3745

class ListInsightsMetricDataResponse < Struct.new(
  :trail_arn,
  :event_source,
  :event_name,
  :insight_type,
  :error_code,
  :timestamps,
  :values,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<Float>

List of values representing the API call rate or error rate at each timestamp. The number of values is equal to the number of timestamps.



3745
3746
3747
3748
3749
3750
3751
3752
3753
3754
3755
3756
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3745

class ListInsightsMetricDataResponse < Struct.new(
  :trail_arn,
  :event_source,
  :event_name,
  :insight_type,
  :error_code,
  :timestamps,
  :values,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end