Class: Aws::CloudTrail::Types::ListQueriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::ListQueriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
Use with
StartTimeto bound aListQueriesrequest, and limit its results to only those queries run within a specified time period. -
#event_data_store ⇒ String
The ARN (or the ID suffix of the ARN) of an event data store on which queries were run.
-
#max_results ⇒ Integer
The maximum number of queries to show on a page.
-
#next_token ⇒ String
A token you can use to get the next page of results.
-
#query_status ⇒ String
The status of queries that you want to return in results.
-
#start_time ⇒ Time
Use with
EndTimeto bound aListQueriesrequest, and limit its results to only those queries run within a specified time period.
Instance Attribute Details
#end_time ⇒ Time
Use with StartTime to bound a ListQueries request, and limit its
results to only those queries run within a specified time period.
3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3841 class ListQueriesRequest < Struct.new( :event_data_store, :next_token, :max_results, :start_time, :end_time, :query_status) SENSITIVE = [] include Aws::Structure end |
#event_data_store ⇒ String
The ARN (or the ID suffix of the ARN) of an event data store on which queries were run.
3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3841 class ListQueriesRequest < Struct.new( :event_data_store, :next_token, :max_results, :start_time, :end_time, :query_status) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of queries to show on a page.
3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3841 class ListQueriesRequest < Struct.new( :event_data_store, :next_token, :max_results, :start_time, :end_time, :query_status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token you can use to get the next page of results.
3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3841 class ListQueriesRequest < Struct.new( :event_data_store, :next_token, :max_results, :start_time, :end_time, :query_status) SENSITIVE = [] include Aws::Structure end |
#query_status ⇒ String
The status of queries that you want to return in results. Valid
values for QueryStatus include QUEUED, RUNNING, FINISHED,
FAILED, TIMED_OUT, or CANCELLED.
3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3841 class ListQueriesRequest < Struct.new( :event_data_store, :next_token, :max_results, :start_time, :end_time, :query_status) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
Use with EndTime to bound a ListQueries request, and limit its
results to only those queries run within a specified time period.
3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3841 class ListQueriesRequest < Struct.new( :event_data_store, :next_token, :max_results, :start_time, :end_time, :query_status) SENSITIVE = [] include Aws::Structure end |