Class: Aws::CloudTrail::Types::ListTrailsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::ListTrailsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to get the next page of results after a previous API call.
Instance Attribute Details
#next_token ⇒ String
The token to use to get the next page of results after a previous API call. This token must be passed in with the same parameters that were specified in the original call. For example, if the original call specified an AttributeKey of 'Username' with a value of 'root', the call with NextToken should include those same parameters.
3933 3934 3935 3936 3937 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3933 class ListTrailsRequest < Struct.new( :next_token) SENSITIVE = [] include Aws::Structure end |