Class: Aws::CloudTrail::Types::PutEventConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_configurationsArray<Types::AggregationConfiguration>

The list of aggregation configurations that you want to configure for the trail.



4208
4209
4210
4211
4212
4213
4214
4215
4216
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4208

class PutEventConfigurationRequest < Struct.new(
  :trail_name,
  :event_data_store,
  :max_event_size,
  :context_key_selectors,
  :aggregation_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#context_key_selectorsArray<Types::ContextKeySelector>

A list of context key selectors that will be included to provide enriched event data.



4208
4209
4210
4211
4212
4213
4214
4215
4216
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4208

class PutEventConfigurationRequest < Struct.new(
  :trail_name,
  :event_data_store,
  :max_event_size,
  :context_key_selectors,
  :aggregation_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#event_data_storeString

The Amazon Resource Name (ARN) or ID suffix of the ARN of the event data store for which event configuration settings are updated.



4208
4209
4210
4211
4212
4213
4214
4215
4216
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4208

class PutEventConfigurationRequest < Struct.new(
  :trail_name,
  :event_data_store,
  :max_event_size,
  :context_key_selectors,
  :aggregation_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#max_event_sizeString

The maximum allowed size for events to be stored in the specified event data store. If you are using context key selectors, MaxEventSize must be set to Large.



4208
4209
4210
4211
4212
4213
4214
4215
4216
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4208

class PutEventConfigurationRequest < Struct.new(
  :trail_name,
  :event_data_store,
  :max_event_size,
  :context_key_selectors,
  :aggregation_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#trail_nameString

The name of the trail for which you want to update event configuration settings.



4208
4209
4210
4211
4212
4213
4214
4215
4216
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4208

class PutEventConfigurationRequest < Struct.new(
  :trail_name,
  :event_data_store,
  :max_event_size,
  :context_key_selectors,
  :aggregation_configurations)
  SENSITIVE = []
  include Aws::Structure
end