Class: Aws::CloudTrail::Types::PutEventSelectorsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::PutEventSelectorsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#advanced_event_selectors ⇒ Array<Types::AdvancedEventSelector>
Specifies the settings for advanced event selectors.
-
#event_selectors ⇒ Array<Types::EventSelector>
Specifies the settings for your event selectors.
-
#trail_name ⇒ String
Specifies the name of the trail or trail ARN.
Instance Attribute Details
#advanced_event_selectors ⇒ Array<Types::AdvancedEventSelector>
Specifies the settings for advanced event selectors. You can use advanced event selectors to log management events, data events for all resource types, and network activity events.
You can add advanced event selectors, and conditions for your
advanced event selectors, up to a maximum of 500 values for all
conditions and selectors on a trail. You can use either
AdvancedEventSelectors or EventSelectors, but not both. If you
apply AdvancedEventSelectors to a trail, any existing
EventSelectors are overwritten. For more information about
advanced event selectors, see Logging data events and Logging
network activity events in the CloudTrail User Guide.
4298 4299 4300 4301 4302 4303 4304 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4298 class PutEventSelectorsRequest < Struct.new( :trail_name, :event_selectors, :advanced_event_selectors) SENSITIVE = [] include Aws::Structure end |
#event_selectors ⇒ Array<Types::EventSelector>
Specifies the settings for your event selectors. You can use event selectors to log management events and data events for the following resource types:
-
AWS::DynamoDB::Table -
AWS::Lambda::Function -
AWS::S3::Object
You can't use event selectors to log network activity events.
You can configure up to five event selectors for a trail. You can
use either EventSelectors or AdvancedEventSelectors in a
PutEventSelectors request, but not both. If you apply
EventSelectors to a trail, any existing AdvancedEventSelectors
are overwritten.
4298 4299 4300 4301 4302 4303 4304 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4298 class PutEventSelectorsRequest < Struct.new( :trail_name, :event_selectors, :advanced_event_selectors) SENSITIVE = [] include Aws::Structure end |
#trail_name ⇒ String
Specifies the name of the trail or trail ARN. If you specify a trail name, the string must meet the following requirements:
-
Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)
-
Start with a letter or number, and end with a letter or number
-
Be between 3 and 128 characters
-
Have no adjacent periods, underscores or dashes. Names like
my-_namespaceandmy--namespaceare not valid. -
Not be in IP address format (for example, 192.168.5.4)
If you specify a trail ARN, it must be in the following format.
arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail
4298 4299 4300 4301 4302 4303 4304 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4298 class PutEventSelectorsRequest < Struct.new( :trail_name, :event_selectors, :advanced_event_selectors) SENSITIVE = [] include Aws::Structure end |