Class: Aws::CloudTrail::Types::PutInsightSelectorsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::PutInsightSelectorsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_data_store ⇒ String
The ARN (or ID suffix of the ARN) of the source event data store for which you want to change or add Insights selectors.
-
#insight_selectors ⇒ Array<Types::InsightSelector>
Contains the Insights types you want to log on a specific category of events on a trail or event data store.
-
#insights_destination ⇒ String
The ARN (or ID suffix of the ARN) of the destination event data store that logs Insights events.
-
#trail_name ⇒ String
The name of the CloudTrail trail for which you want to change or add Insights selectors.
Instance Attribute Details
#event_data_store ⇒ String
The ARN (or ID suffix of the ARN) of the source event data store for
which you want to change or add Insights selectors. To enable
Insights on an event data store, you must provide both the
EventDataStore and InsightsDestination parameters.
You cannot use this parameter with the TrailName parameter.
4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4375 class PutInsightSelectorsRequest < Struct.new( :trail_name, :insight_selectors, :event_data_store, :insights_destination) SENSITIVE = [] include Aws::Structure end |
#insight_selectors ⇒ Array<Types::InsightSelector>
Contains the Insights types you want to log on a specific category
of events on a trail or event data store. ApiCallRateInsight and
ApiErrorRateInsight are valid Insight types.The EventCategory
field can specify Management or Data events or both. For event
data store, you can log Insights for management events only.
The ApiCallRateInsight Insights type analyzes write-only
management API calls or read and write data API calls that are
aggregated per minute against a baseline API call volume.
The ApiErrorRateInsight Insights type analyzes management and data
API calls that result in error codes. The error is shown if the API
call is unsuccessful.
4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4375 class PutInsightSelectorsRequest < Struct.new( :trail_name, :insight_selectors, :event_data_store, :insights_destination) SENSITIVE = [] include Aws::Structure end |
#insights_destination ⇒ String
The ARN (or ID suffix of the ARN) of the destination event data
store that logs Insights events. To enable Insights on an event data
store, you must provide both the EventDataStore and
InsightsDestination parameters.
You cannot use this parameter with the TrailName parameter.
4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4375 class PutInsightSelectorsRequest < Struct.new( :trail_name, :insight_selectors, :event_data_store, :insights_destination) SENSITIVE = [] include Aws::Structure end |
#trail_name ⇒ String
The name of the CloudTrail trail for which you want to change or add Insights selectors.
You cannot use this parameter with the EventDataStore and
InsightsDestination parameters.
4375 4376 4377 4378 4379 4380 4381 4382 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4375 class PutInsightSelectorsRequest < Struct.new( :trail_name, :insight_selectors, :event_data_store, :insights_destination) SENSITIVE = [] include Aws::Structure end |