Class: Aws::CloudTrail::Types::PutInsightSelectorsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_data_store_arnString

The Amazon Resource Name (ARN) of the source event data store for which you want to change or add Insights selectors.

Returns:

  • (String)


4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4429

class PutInsightSelectorsResponse < Struct.new(
  :trail_arn,
  :insight_selectors,
  :event_data_store_arn,
  :insights_destination)
  SENSITIVE = []
  include Aws::Structure
end

#insight_selectorsArray<Types::InsightSelector>

Contains the Insights types you want to log on a specific category of events in a trail or event data store. ApiCallRateInsight and ApiErrorRateInsight are valid Insight types.The EventCategory field can specify Management or Data events or both. For event data store, you can only log Insights for management events only.

Returns:



4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4429

class PutInsightSelectorsResponse < Struct.new(
  :trail_arn,
  :insight_selectors,
  :event_data_store_arn,
  :insights_destination)
  SENSITIVE = []
  include Aws::Structure
end

#insights_destinationString

The ARN of the destination event data store that logs Insights events.

Returns:

  • (String)


4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4429

class PutInsightSelectorsResponse < Struct.new(
  :trail_arn,
  :insight_selectors,
  :event_data_store_arn,
  :insights_destination)
  SENSITIVE = []
  include Aws::Structure
end

#trail_arnString

The Amazon Resource Name (ARN) of a trail for which you want to change or add Insights selectors.

Returns:

  • (String)


4429
4430
4431
4432
4433
4434
4435
4436
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4429

class PutInsightSelectorsResponse < Struct.new(
  :trail_arn,
  :insight_selectors,
  :event_data_store_arn,
  :insights_destination)
  SENSITIVE = []
  include Aws::Structure
end