Class: Aws::CloudTrail::Types::QueryStatisticsForDescribeQuery
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::QueryStatisticsForDescribeQuery
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Gets metadata about a query, including the number of events that were matched, the total number of events scanned, the query run time in milliseconds, and the query's creation time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes_scanned ⇒ Integer
The total bytes that the query scanned in the event data store.
-
#creation_time ⇒ Time
The creation time of the query.
-
#events_matched ⇒ Integer
The number of events that matched a query.
-
#events_scanned ⇒ Integer
The number of events that the query scanned in the event data store.
-
#execution_time_in_millis ⇒ Integer
The query's run time, in milliseconds.
Instance Attribute Details
#bytes_scanned ⇒ Integer
The total bytes that the query scanned in the event data store. This value matches the number of bytes for which your account is billed for the query, unless the query is still running.
4601 4602 4603 4604 4605 4606 4607 4608 4609 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4601 class QueryStatisticsForDescribeQuery < Struct.new( :events_matched, :events_scanned, :bytes_scanned, :execution_time_in_millis, :creation_time) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The creation time of the query.
4601 4602 4603 4604 4605 4606 4607 4608 4609 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4601 class QueryStatisticsForDescribeQuery < Struct.new( :events_matched, :events_scanned, :bytes_scanned, :execution_time_in_millis, :creation_time) SENSITIVE = [] include Aws::Structure end |
#events_matched ⇒ Integer
The number of events that matched a query.
4601 4602 4603 4604 4605 4606 4607 4608 4609 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4601 class QueryStatisticsForDescribeQuery < Struct.new( :events_matched, :events_scanned, :bytes_scanned, :execution_time_in_millis, :creation_time) SENSITIVE = [] include Aws::Structure end |
#events_scanned ⇒ Integer
The number of events that the query scanned in the event data store.
4601 4602 4603 4604 4605 4606 4607 4608 4609 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4601 class QueryStatisticsForDescribeQuery < Struct.new( :events_matched, :events_scanned, :bytes_scanned, :execution_time_in_millis, :creation_time) SENSITIVE = [] include Aws::Structure end |
#execution_time_in_millis ⇒ Integer
The query's run time, in milliseconds.
4601 4602 4603 4604 4605 4606 4607 4608 4609 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4601 class QueryStatisticsForDescribeQuery < Struct.new( :events_matched, :events_scanned, :bytes_scanned, :execution_time_in_millis, :creation_time) SENSITIVE = [] include Aws::Structure end |