Class: Aws::CloudTrail::Types::RefreshScheduleFrequency
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::RefreshScheduleFrequency
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Specifies the frequency for a dashboard refresh schedule.
For a custom dashboard, you can schedule a refresh for every 1, 6, 12, or 24 hours, or every day.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unit ⇒ String
The unit to use for the refresh.
-
#value ⇒ Integer
The value for the refresh schedule.
Instance Attribute Details
#unit ⇒ String
The unit to use for the refresh.
For custom dashboards, the unit can be HOURS or DAYS.
For the Highlights dashboard, the Unit must be HOURS.
4665 4666 4667 4668 4669 4670 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4665 class RefreshScheduleFrequency < Struct.new( :unit, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Integer
The value for the refresh schedule.
For custom dashboards, the following values are valid when the unit
is HOURS: 1, 6, 12, 24
For custom dashboards, the only valid value when the unit is DAYS
is 1.
For the Highlights dashboard, the Value must be 6.
4665 4666 4667 4668 4669 4670 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4665 class RefreshScheduleFrequency < Struct.new( :unit, :value) SENSITIVE = [] include Aws::Structure end |