Class: Aws::CloudTrail::Types::RestoreEventDataStoreResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#advanced_event_selectorsArray<Types::AdvancedEventSelector>

The advanced event selectors that were used to select events.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#billing_modeString

The billing mode for the event data store.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#created_timestampTime

The timestamp of an event data store's creation.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#event_data_store_arnString

The event data store ARN.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

Specifies the KMS key ID that encrypts the events delivered by CloudTrail. The value is a fully specified ARN to a KMS key in the following format.

arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#multi_region_enabledBoolean

Indicates whether the event data store is collecting events from all Regions, or only from the Region in which the event data store was created.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the event data store.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#organization_enabledBoolean

Indicates whether an event data store is collecting logged events for an organization in Organizations.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#retention_periodInteger

The retention period, in days.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the event data store.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#termination_protection_enabledBoolean

Indicates that termination protection is enabled and the event data store cannot be automatically deleted.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end

#updated_timestampTime

The timestamp that shows when an event data store was updated, if applicable. UpdatedTimestamp is always either the same or newer than the time shown in CreatedTimestamp.



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
4952
4953
4954
4955
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4940

class RestoreEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode)
  SENSITIVE = []
  include Aws::Structure
end