Class: Aws::CloudTrail::Types::SearchSampleQueriesSearchResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::SearchSampleQueriesSearchResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
A search result returned by the SearchSampleQueries operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A longer description of a sample query.
-
#name ⇒ String
The name of a sample query.
-
#relevance ⇒ Float
A value between 0 and 1 indicating the similarity between the search phrase and result.
-
#sql ⇒ String
The SQL code of the sample query.
Instance Attribute Details
#description ⇒ String
A longer description of a sample query.
5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5052 class SearchSampleQueriesSearchResult < Struct.new( :name, :description, :sql, :relevance) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of a sample query.
5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5052 class SearchSampleQueriesSearchResult < Struct.new( :name, :description, :sql, :relevance) SENSITIVE = [] include Aws::Structure end |
#relevance ⇒ Float
A value between 0 and 1 indicating the similarity between the search phrase and result.
5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5052 class SearchSampleQueriesSearchResult < Struct.new( :name, :description, :sql, :relevance) SENSITIVE = [] include Aws::Structure end |
#sql ⇒ String
The SQL code of the sample query.
5052 5053 5054 5055 5056 5057 5058 5059 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5052 class SearchSampleQueriesSearchResult < Struct.new( :name, :description, :sql, :relevance) SENSITIVE = [] include Aws::Structure end |