Class: Aws::CloudTrail::Types::StartImportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::StartImportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The timestamp for the import’s creation.
-
#destinations ⇒ Array<String>
The ARN of the destination event data store.
-
#end_event_time ⇒ Time
Used with
StartEventTimeto bound aStartImportrequest, and limit imported trail events to only those events logged within a specified time period. -
#import_id ⇒ String
The ID of the import.
-
#import_source ⇒ Types::ImportSource
The source S3 bucket for the import.
-
#import_status ⇒ String
Shows the status of the import after a
StartImportrequest. -
#start_event_time ⇒ Time
Used with
EndEventTimeto bound aStartImportrequest, and limit imported trail events to only those events logged within a specified time period. -
#updated_timestamp ⇒ Time
The timestamp of the import’s last update, if applicable.
Instance Attribute Details
#created_timestamp ⇒ Time
The timestamp for the import’s creation.
5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5211 class StartImportResponse < Struct.new( :import_id, :destinations, :import_source, :start_event_time, :end_event_time, :import_status, :created_timestamp, :updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<String>
The ARN of the destination event data store.
5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5211 class StartImportResponse < Struct.new( :import_id, :destinations, :import_source, :start_event_time, :end_event_time, :import_status, :created_timestamp, :updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#end_event_time ⇒ Time
Used with StartEventTime to bound a StartImport request, and limit imported trail events to only those events logged within a specified time period.
5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5211 class StartImportResponse < Struct.new( :import_id, :destinations, :import_source, :start_event_time, :end_event_time, :import_status, :created_timestamp, :updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#import_id ⇒ String
The ID of the import.
5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5211 class StartImportResponse < Struct.new( :import_id, :destinations, :import_source, :start_event_time, :end_event_time, :import_status, :created_timestamp, :updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#import_source ⇒ Types::ImportSource
The source S3 bucket for the import.
5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5211 class StartImportResponse < Struct.new( :import_id, :destinations, :import_source, :start_event_time, :end_event_time, :import_status, :created_timestamp, :updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#import_status ⇒ String
Shows the status of the import after a StartImport request. An import finishes with a status of COMPLETED if there were no failures, or FAILED if there were failures.
5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5211 class StartImportResponse < Struct.new( :import_id, :destinations, :import_source, :start_event_time, :end_event_time, :import_status, :created_timestamp, :updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#start_event_time ⇒ Time
Used with EndEventTime to bound a StartImport request, and limit imported trail events to only those events logged within a specified time period.
5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5211 class StartImportResponse < Struct.new( :import_id, :destinations, :import_source, :start_event_time, :end_event_time, :import_status, :created_timestamp, :updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#updated_timestamp ⇒ Time
The timestamp of the import’s last update, if applicable.
5211 5212 5213 5214 5215 5216 5217 5218 5219 5220 5221 5222 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5211 class StartImportResponse < Struct.new( :import_id, :destinations, :import_source, :start_event_time, :end_event_time, :import_status, :created_timestamp, :updated_timestamp) SENSITIVE = [] include Aws::Structure end |