Class: Aws::CloudTrail::Types::Trail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

The settings for a trail.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watch_logs_log_group_arnString

Specifies an Amazon Resource Name (ARN), a unique identifier that represents the log group to which CloudTrail logs will be delivered.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#cloud_watch_logs_role_arnString

Specifies the role for the CloudWatch Logs endpoint to assume to write to a user's log group.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#has_custom_event_selectorsBoolean

Specifies if the trail has custom event selectors.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#has_insight_selectorsBoolean

Specifies whether a trail has insight types specified in an InsightSelector list.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#home_regionString

The Region in which the trail was created.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#include_global_service_eventsBoolean

Set to True to include Amazon Web Services API calls from Amazon Web Services global services such as IAM. Otherwise, False. Setting this value to true only delivers global service events to the trail if the trail is multi-Region or if the trail's home Region is the partition leader Region (for example, us-east-1).



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#is_multi_region_trailBoolean

Specifies whether the trail exists only in one Region or exists in all Regions.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#is_organization_trailBoolean

Specifies whether the trail is an organization trail.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

Specifies the KMS key ID that encrypts the logs and digest files delivered by CloudTrail. The value is a fully specified ARN to a KMS key in the following format.

arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#log_file_validation_enabledBoolean

Specifies whether log file validation is enabled.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Name of the trail set by calling CreateTrail. The maximum length is 128 characters.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#recursive_loggingBoolean

Specifies whether recursive logging is enabled for the trail. If you set RecursiveLogging to false, CloudTrail suppresses events generated by CloudTrail when it delivers log files to your trail's destinations, including Amazon S3 and CloudWatch Logs. The default value is true.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_nameString

Name of the Amazon S3 bucket into which CloudTrail delivers your trail files. See Amazon S3 Bucket naming rules.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#s3_key_prefixString

Specifies the Amazon S3 key prefix that comes after the name of the bucket you have designated for log file delivery. For more information, see Finding Your CloudTrail Log Files. The maximum length is 200 characters.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_arnString

Specifies the ARN of the Amazon SNS topic that CloudTrail uses to send notifications when log files are delivered. The following is the format of a topic ARN.

arn:aws:sns:us-east-2:123456789012:MyTopic



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_nameString

This field is no longer in use. Use SnsTopicARN.



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end

#trail_arnString

Specifies the ARN of the trail. The following is the format of a trail ARN.

arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail



5575
5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
5594
5595
# File 'lib/aws-sdk-cloudtrail/types.rb', line 5575

class Trail < Struct.new(
  :name,
  :s3_bucket_name,
  :s3_key_prefix,
  :sns_topic_name,
  :sns_topic_arn,
  :include_global_service_events,
  :is_multi_region_trail,
  :home_region,
  :trail_arn,
  :log_file_validation_enabled,
  :cloud_watch_logs_log_group_arn,
  :cloud_watch_logs_role_arn,
  :kms_key_id,
  :has_custom_event_selectors,
  :has_insight_selectors,
  :is_organization_trail,
  :recursive_logging)
  SENSITIVE = []
  include Aws::Structure
end