Class: Aws::CloudTrail::Types::UpdateEventDataStoreResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#advanced_event_selectorsArray<Types::AdvancedEventSelector>

The advanced event selectors that are applied to the event data store.

Returns:



6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#billing_modeString

The billing mode for the event data store.

Returns:

  • (String)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#created_timestampTime

The timestamp that shows when an event data store was first created.

Returns:

  • (Time)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#event_data_store_arnString

The ARN of the event data store.

Returns:

  • (String)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#federation_role_arnString

If Lake query federation is enabled, provides the ARN of the federation role used to access the resources for the federated event data store.

Returns:

  • (String)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#federation_statusString

Indicates the Lake query federation status. The status is ENABLED if Lake query federation is enabled, or DISABLED if Lake query federation is disabled. You cannot delete an event data store if the FederationStatus is ENABLED.

Returns:

  • (String)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

Specifies the KMS key ID that encrypts the events delivered by CloudTrail. The value is a fully specified ARN to a KMS key in the following format.

arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012

Returns:

  • (String)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#multi_region_enabledBoolean

Indicates whether the event data store includes events from all Regions, or only from the Region in which it was created.

Returns:

  • (Boolean)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the event data store.

Returns:

  • (String)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#organization_enabledBoolean

Indicates whether an event data store is collecting logged events for an organization in Organizations.

Returns:

  • (Boolean)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#retention_periodInteger

The retention period, in days.

Returns:

  • (Integer)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of an event data store.

Returns:

  • (String)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#termination_protection_enabledBoolean

Indicates whether termination protection is enabled for the event data store.

Returns:

  • (Boolean)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#updated_timestampTime

The timestamp that shows when the event data store was last updated. UpdatedTimestamp is always either the same or newer than the time shown in CreatedTimestamp.

Returns:

  • (Time)


6005
6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
# File 'lib/aws-sdk-cloudtrail/types.rb', line 6005

class UpdateEventDataStoreResponse < Struct.new(
  :event_data_store_arn,
  :name,
  :status,
  :advanced_event_selectors,
  :multi_region_enabled,
  :organization_enabled,
  :retention_period,
  :termination_protection_enabled,
  :created_timestamp,
  :updated_timestamp,
  :kms_key_id,
  :billing_mode,
  :federation_status,
  :federation_role_arn)
  SENSITIVE = []
  include Aws::Structure
end