Class: Aws::CloudTrail::Types::ListDashboardsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::ListDashboardsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of dashboards to display on a single page.
-
#name_prefix ⇒ String
Specify a name prefix to filter on.
-
#next_token ⇒ String
A token you can use to get the next page of dashboard results.
-
#type ⇒ String
Specify a dashboard type to filter on:
CUSTOMorMANAGED.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of dashboards to display on a single page.
3377 3378 3379 3380 3381 3382 3383 3384 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3377 class ListDashboardsRequest < Struct.new( :name_prefix, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#name_prefix ⇒ String
Specify a name prefix to filter on.
3377 3378 3379 3380 3381 3382 3383 3384 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3377 class ListDashboardsRequest < Struct.new( :name_prefix, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token you can use to get the next page of dashboard results.
3377 3378 3379 3380 3381 3382 3383 3384 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3377 class ListDashboardsRequest < Struct.new( :name_prefix, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specify a dashboard type to filter on: CUSTOM or MANAGED.
3377 3378 3379 3380 3381 3382 3383 3384 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3377 class ListDashboardsRequest < Struct.new( :name_prefix, :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |