Class: Aws::CloudTrail::Types::ListInsightsMetricDataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::ListInsightsMetricDataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_type ⇒ String
Type of data points to return.
-
#end_time ⇒ Time
Specifies, in UTC, the end time for time-series data.
-
#error_code ⇒ String
Conditionally required if the
InsightTypeparameter is set toApiErrorRateInsight. -
#event_name ⇒ String
The name of the event, typically the Amazon Web Services API on which unusual levels of activity were recorded.
-
#event_source ⇒ String
The Amazon Web Services service to which the request was made, such as
iam.amazonaws.comors3.amazonaws.com. -
#insight_type ⇒ String
The type of CloudTrail Insights event, which is either
ApiCallRateInsightorApiErrorRateInsight. -
#max_results ⇒ Integer
The maximum number of data points to return.
-
#next_token ⇒ String
Returned if all datapoints can't be returned in a single call.
-
#period ⇒ Integer
Granularity of data to retrieve, in seconds.
-
#start_time ⇒ Time
Specifies, in UTC, the start time for time-series data.
-
#trail_name ⇒ String
The Amazon Resource Name(ARN) or name of the trail for which you want to retrieve Insights metrics data.
Instance Attribute Details
#data_type ⇒ String
Type of data points to return. Valid values are NonZeroData and
FillWithZeros. The default is NonZeroData.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
Specifies, in UTC, the end time for time-series data. The value specified is exclusive; results include data points up to the specified time stamp.
The default is the time of request.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#error_code ⇒ String
Conditionally required if the InsightType parameter is set to
ApiErrorRateInsight.
If returning metrics for the ApiErrorRateInsight Insights type,
this is the error to retrieve data for. For example, AccessDenied.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#event_name ⇒ String
The name of the event, typically the Amazon Web Services API on which unusual levels of activity were recorded.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#event_source ⇒ String
The Amazon Web Services service to which the request was made, such
as iam.amazonaws.com or s3.amazonaws.com.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#insight_type ⇒ String
The type of CloudTrail Insights event, which is either
ApiCallRateInsight or ApiErrorRateInsight. The
ApiCallRateInsight Insights type analyzes write-only management
API calls that are aggregated per minute against a baseline API call
volume. The ApiErrorRateInsight Insights type analyzes management
API calls that result in error codes.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of data points to return. Valid values are integers from 1 to 21600. The default value is 21600.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Returned if all datapoints can't be returned in a single call. For
example, due to reaching MaxResults.
Add this parameter to the request to continue retrieving results starting from the last evaluated point.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#period ⇒ Integer
Granularity of data to retrieve, in seconds. Valid values are 60,
300, and 3600. If you specify any other value, you will get an
error. The default is 3600 seconds.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
Specifies, in UTC, the start time for time-series data. The value specified is inclusive; results include data points with the specified time stamp.
The default is 90 days before the time of request.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#trail_name ⇒ String
The Amazon Resource Name(ARN) or name of the trail for which you want to retrieve Insights metrics data. This parameter should only be provided to fetch Insights metrics data generated on trails logging data events. This parameter is not required for Insights metric data generated on trails logging management events.
3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 3678 class ListInsightsMetricDataRequest < Struct.new( :trail_name, :event_source, :event_name, :insight_type, :error_code, :start_time, :end_time, :period, :data_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |