Class: Aws::CloudTrail::Types::RefreshSchedule
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudTrail::Types::RefreshSchedule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudtrail/types.rb
Overview
The schedule for a dashboard refresh.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#frequency ⇒ Types::RefreshScheduleFrequency
The frequency at which you want the dashboard refreshed.
-
#status ⇒ String
Specifies whether the refresh schedule is enabled.
-
#time_of_day ⇒ String
The time of day in UTC to run the schedule; for hourly only refer to minutes; default is 00:00.
Instance Attribute Details
#frequency ⇒ Types::RefreshScheduleFrequency
The frequency at which you want the dashboard refreshed.
4630 4631 4632 4633 4634 4635 4636 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4630 class RefreshSchedule < Struct.new( :frequency, :status, :time_of_day) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Specifies whether the refresh schedule is enabled. Set the value to
ENABLED to enable the refresh schedule, or to DISABLED to turn
off the refresh schedule.
4630 4631 4632 4633 4634 4635 4636 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4630 class RefreshSchedule < Struct.new( :frequency, :status, :time_of_day) SENSITIVE = [] include Aws::Structure end |
#time_of_day ⇒ String
The time of day in UTC to run the schedule; for hourly only refer to minutes; default is 00:00.
4630 4631 4632 4633 4634 4635 4636 |
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4630 class RefreshSchedule < Struct.new( :frequency, :status, :time_of_day) SENSITIVE = [] include Aws::Structure end |