Class: Aws::CloudTrail::Types::RefreshScheduleFrequency

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudtrail/types.rb

Overview

Specifies the frequency for a dashboard refresh schedule.

For a custom dashboard, you can schedule a refresh for every 1, 6, 12, or 24 hours, or every day.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unitString

The unit to use for the refresh.

For custom dashboards, the unit can be HOURS or DAYS.

For the Highlights dashboard, the Unit must be HOURS.



4645
4646
4647
4648
4649
4650
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4645

class RefreshScheduleFrequency < Struct.new(
  :unit,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueInteger

The value for the refresh schedule.

For custom dashboards, the following values are valid when the unit is HOURS: 1, 6, 12, 24

For custom dashboards, the only valid value when the unit is DAYS is 1.

For the Highlights dashboard, the Value must be 6.



4645
4646
4647
4648
4649
4650
# File 'lib/aws-sdk-cloudtrail/types.rb', line 4645

class RefreshScheduleFrequency < Struct.new(
  :unit,
  :value)
  SENSITIVE = []
  include Aws::Structure
end